window.Gleam.initSearch([{"doc":"gleam_erlang","title":"gleam_erlang","content":"# Gleam Erlang 🐙\n\nA library for making use of Erlang specific code!\n\n## Features\n\n- Typed Erlang processes and message sending.\n- Erlang binary format (de)serialisation.\n- Functions for working with Erlang&#39;s charlists.\n- Reading, writing, and deletion of files.\n- Basic distributed Erlang support and working with nodes.\n- Reading and writing of environment variables.\n- Functions for working with atoms.\n\n## Usage\n\nAdd this library to your Gleam project\n\n```shell\ngleam add gleam_erlang\n```\n\nAnd then use it in your code\n\n```gleam\nimport gleam/io\nimport gleam/erlang/file\n\npub fn main() {\n  assert Ok(contents) = file.read(&quot;pokedex.txt&quot;)\n  io.println(contents)\n}\n```\n\nDocumentation can be found at &lt;https://hexdocs.pm/gleam_erlang/&gt;.\n\nThis library requires OTP 23.0 or higher.\n","url":"index.html"},{"doc":"gleam/erlang/os","title":"OsFamily","content":"pub type OsFamily {\n  WindowsNt\n  Linux\n  Darwin\n  FreeBsd\n  Other(String)\n}\n Represents operating system kernels\nWindowsNt\n\n\nLinux\n\n\nDarwin\n\n\nFreeBsd\n\n\nOther(String)\n\n\nSynonyms:\ngleam/erlang/os.OsFamily\ngleam/erlang/os OsFamily","url":"gleam/erlang/os.html#OsFamily"},{"doc":"gleam/erlang/os","title":"family","content":"pub fn family() -&gt; OsFamily\n Returns the kernel of the host operating system.\n\n Unknown kernels are reported as `Other(String)`; e.g. `Other(&quot;sunos&quot;)`.\n\n ## Examples\n\n    &gt; family()\n    Linux\n    &gt; family()\n    Darwin\n    &gt; family()\n    Other(&quot;sunos&quot;)\n\nSynonyms:\ngleam/erlang/os.family\ngleam/erlang/os family","url":"gleam/erlang/os.html#family"},{"doc":"gleam/erlang/os","title":"get_all_env","content":"pub fn get_all_env() -&gt; Map(String, String)\n Returns the list of all available environment variables as a list of key,\n tuples.\n\n ## Examples\n\n    &gt; get_all_env()\n    map.from_list([\n      #(&quot;SHELL&quot;, &quot;/bin/bash&quot;),\n      #(&quot;PWD&quot;, &quot;/home/j3rn&quot;),\n      ...\n    ])\n\nSynonyms:\ngleam/erlang/os.get_all_env\ngleam/erlang/os get_all_env","url":"gleam/erlang/os.html#get_all_env"},{"doc":"gleam/erlang/os","title":"get_env","content":"pub fn get_env(name name: String) -&gt; Result(String, Nil)\n Returns the value associated with the given environment variable name.\n\n ## Examples\n\n    &gt; get_env(&quot;SHELL&quot;)\n    &quot;/bin/bash&quot;\n\n    &gt; get_env(name: &quot;PWD&quot;)\n    &quot;/home/j3rn&quot;\n\nSynonyms:\ngleam/erlang/os.get_env\ngleam/erlang/os get_env","url":"gleam/erlang/os.html#get_env"},{"doc":"gleam/erlang/os","title":"set_env","content":"pub fn set_env(name name: String, value value: String) -&gt; Nil\n Associates the given value with the given environment variable name.\n\n ## Examples\n\n    &gt; set_env(&quot;MYVAR&quot;, &quot;MYVALUE&quot;)\n    Nil\n    &gt; get_env(&quot;MYVAR&quot;)\n    &quot;MYVALUE&quot;\n\n    &gt; set_env(value: &quot;MYVALUE&quot;, name: &quot;MYVAR&quot;)\n    Nil\n\nSynonyms:\ngleam/erlang/os.set_env\ngleam/erlang/os set_env","url":"gleam/erlang/os.html#set_env"},{"doc":"gleam/erlang/os","title":"unset_env","content":"pub fn unset_env(name name: String) -&gt; Nil\n Removes the environment variable with the given name.\n\n Returns Nil regardless of whether the variable ever existed.\n\n ## Examples\n\n    &gt; get_env(&quot;MYVAR&quot;)\n    Ok(&quot;MYVALUE&quot;)\n    &gt; unset_env(&quot;MYVAR&quot;)\n    Nil\n    &gt; get_env(&quot;MYVAR&quot;)\n    Error(Nil)\n\n    &gt; unset_env(name: &quot;MYVAR&quot;)\n    Nil\n\nSynonyms:\ngleam/erlang/os.unset_env\ngleam/erlang/os unset_env","url":"gleam/erlang/os.html#unset_env"},{"doc":"gleam/erlang/os","title":"gleam/erlang/os","content":" Access to the shell&#39;s environment variables","url":"gleam/erlang/os.html"},{"doc":"gleam/erlang/atom","title":"Atom","content":"pub type Atom\n Atom is a special string-like data-type that is most commonly used for\n interfacing with code written in other BEAM languages such as Erlang and\n Elixir. It is preferable to define your own custom types to use instead of\n atoms where possible.\n\n Atoms are not used much in typical Gleam code!\n\n ## Creating atoms\n\n We can create atoms with the the [`create_from_string`](#create_from_string)\n function, though we must be careful when doing so as atoms are never\n garbage collected. If we create too many atoms (for example, if we convert\n user input into atoms) we may hit the max limit of atoms and cause the\n virtual machine to crash.\n\n\nSynonyms:\ngleam/erlang/atom.Atom\ngleam/erlang/atom Atom","url":"gleam/erlang/atom.html#Atom"},{"doc":"gleam/erlang/atom","title":"FromStringError","content":"pub type FromStringError {\n  AtomNotLoaded\n}\n An error returned when no atom is found in the virtual machine&#39;s atom table\n for a given string when calling the [`from_string`](#from_string) function.\nAtomNotLoaded\n\n\nSynonyms:\ngleam/erlang/atom.FromStringError\ngleam/erlang/atom FromStringError","url":"gleam/erlang/atom.html#FromStringError"},{"doc":"gleam/erlang/atom","title":"create_from_string","content":"pub fn create_from_string(a: String) -&gt; Atom\n Creates an atom from a string, inserting a new value into the virtual\n machine&#39;s atom table if an atom does not already exist for the given\n string.\n\n We must be careful when using this function as there is a limit to the\n number of atom that can fit in the virtual machine&#39;s atom table. Never\n convert user input into atoms as filling the atom table will cause the\n virtual machine to crash!\n\nSynonyms:\ngleam/erlang/atom.create_from_string\ngleam/erlang/atom create_from_string","url":"gleam/erlang/atom.html#create_from_string"},{"doc":"gleam/erlang/atom","title":"from_dynamic","content":"pub fn from_dynamic(from from: Dynamic) -&gt; Result(\n  Atom,\n  List(DecodeError),\n)\n Checks to see whether a `Dynamic` value is an atom, and return the atom if\n it is.\n\n ## Examples\n\n    &gt; import gleam/dynamic\n    &gt; from_dynamic(dynamic.from(create_from_string(&quot;hello&quot;)))\n    Ok(create_from_string(&quot;hello&quot;))\n\n    &gt; from_dynamic(dynamic.from(123))\n    Error([DecodeError(expected: &quot;Atom&quot;, found: &quot;Int&quot;, path: [])])\n\nSynonyms:\ngleam/erlang/atom.from_dynamic\ngleam/erlang/atom from_dynamic","url":"gleam/erlang/atom.html#from_dynamic"},{"doc":"gleam/erlang/atom","title":"from_string","content":"pub fn from_string(a: String) -&gt; Result(Atom, FromStringError)\n Finds an existing Atom for the given String.\n\n If no atom is found in the virtual machine&#39;s atom table for the String then\n an error is returned.\n\n ## Examples\n\n    &gt; from_string(&quot;ok&quot;)\n    Ok(create_from_string(&quot;ok&quot;))\n\n    &gt; from_string(&quot;some_new_atom&quot;)\n    Error(AtomNotLoaded)\n\nSynonyms:\ngleam/erlang/atom.from_string\ngleam/erlang/atom from_string","url":"gleam/erlang/atom.html#from_string"},{"doc":"gleam/erlang/atom","title":"to_string","content":"pub fn to_string(a: Atom) -&gt; String\n Retuns a `String` corresponding to the text representation of the given\n `Atom`.\n\n ## Examples\n\n    &gt; let ok_atom = create_from_string(&quot;ok&quot;)\n    &gt; to_string(ok_atom)\n    &quot;ok&quot;\n\nSynonyms:\ngleam/erlang/atom.to_string\ngleam/erlang/atom to_string","url":"gleam/erlang/atom.html#to_string"},{"doc":"gleam/erlang/atom","title":"gleam/erlang/atom","content":"","url":"gleam/erlang/atom.html"},{"doc":"gleam/erlang/charlist","title":"Charlist","content":"pub type Charlist\n A list of characters represented as ints. Commonly used by older Erlang\n modules.\n\nSynonyms:\ngleam/erlang/charlist.Charlist\ngleam/erlang/charlist Charlist","url":"gleam/erlang/charlist.html#Charlist"},{"doc":"gleam/erlang/charlist","title":"from_string","content":"pub fn from_string(a: String) -&gt; Charlist\n Transform a string to a charlist\nSynonyms:\ngleam/erlang/charlist.from_string\ngleam/erlang/charlist from_string","url":"gleam/erlang/charlist.html#from_string"},{"doc":"gleam/erlang/charlist","title":"to_string","content":"pub fn to_string(a: Charlist) -&gt; String\n Transform a charlist to a string\nSynonyms:\ngleam/erlang/charlist.to_string\ngleam/erlang/charlist to_string","url":"gleam/erlang/charlist.html#to_string"},{"doc":"gleam/erlang/charlist","title":"gleam/erlang/charlist","content":" A charlist is a list of integers where all the integers are valid code\n points.\n\n In practice, you will not come across them often, except perhaps when\n interfacing with Erlang, in particular when using older libraries that do\n not accept binaries as arguments.","url":"gleam/erlang/charlist.html"},{"doc":"gleam/erlang","title":"Crash","content":"pub type Crash {\n  Exited(Dynamic)\n  Thrown(Dynamic)\n  Errored(Dynamic)\n}\n\nExited(Dynamic)\n\n\nThrown(Dynamic)\n\n\nErrored(Dynamic)\n\n\nSynonyms:\ngleam/erlang.Crash\ngleam/erlang Crash","url":"gleam/erlang.html#Crash"},{"doc":"gleam/erlang","title":"EnsureAllStartedError","content":"pub type EnsureAllStartedError {\n  UnknownApplication(name: Atom)\n  ApplicationFailedToStart(name: Atom, reason: Dynamic)\n}\n\nUnknownApplication(name: Atom)\n\n\nApplicationFailedToStart(name: Atom, reason: Dynamic)\n\n\nSynonyms:\ngleam/erlang.EnsureAllStartedError\ngleam/erlang EnsureAllStartedError","url":"gleam/erlang.html#EnsureAllStartedError"},{"doc":"gleam/erlang","title":"GetLineError","content":"pub type GetLineError {\n  Eof\n  NoData\n}\n Error value returned by `get_line` function\n\nEof\n\n\nNoData\n\n\nSynonyms:\ngleam/erlang.GetLineError\ngleam/erlang GetLineError","url":"gleam/erlang.html#GetLineError"},{"doc":"gleam/erlang","title":"Reference","content":"pub type Reference\n A unique reference value.\n\n It holds no particular meaning or value, but unique values are often useful\n in programs are used heavily within both Gleam and Erlang&#39;s OTP frameworks.\n\n More can be read about refernces in the [Erlang documentation][1].\n\n [1]: https://www.erlang.org/doc/efficiency_guide/advanced.html#unique_references\n\n\nSynonyms:\ngleam/erlang.Reference\ngleam/erlang Reference","url":"gleam/erlang.html#Reference"},{"doc":"gleam/erlang","title":"TimeUnit","content":"pub type TimeUnit {\n  Second\n  Millisecond\n  Microsecond\n  Nanosecond\n}\n\nSecond\n\n\nMillisecond\n\n\nMicrosecond\n\n\nNanosecond\n\n\nSynonyms:\ngleam/erlang.TimeUnit\ngleam/erlang TimeUnit","url":"gleam/erlang.html#TimeUnit"},{"doc":"gleam/erlang","title":"binary_to_term","content":"pub fn binary_to_term(binary: BitString) -&gt; Result(Dynamic, Nil)\n\nSynonyms:\ngleam/erlang.binary_to_term\ngleam/erlang binary_to_term","url":"gleam/erlang.html#binary_to_term"},{"doc":"gleam/erlang","title":"ensure_all_started","content":"pub fn ensure_all_started(application application: Atom) -&gt; Result(\n  List(Atom),\n  EnsureAllStartedError,\n)\n Starts an OTP application&#39;s process tree in the background, as well as\n the trees of any applications that the given application depends upon. An\n OTP application typically maps onto a Gleam or Hex package.\n\n Returns a list of the applications that were started. Calling this function\n for application that have already been started is a no-op so you do not need\n to check the application state beforehand.\n\n In Gleam we prefer to not use these implicit background process trees, but\n you will likely still need to start the trees of OTP applications written in\n other BEAM languages such as Erlang or Elixir, including those included by\n default with Erlang/OTP.\n\n For more information see the OTP documentation.\n - &lt;https://www.erlang.org/doc/man/application.html#ensure_all_started-1&gt;\n - &lt;https://www.erlang.org/doc/man/application.html#start-1&gt;\n\nSynonyms:\ngleam/erlang.ensure_all_started\ngleam/erlang ensure_all_started","url":"gleam/erlang.html#ensure_all_started"},{"doc":"gleam/erlang","title":"erlang_timestamp","content":"pub fn erlang_timestamp() -&gt; #(Int, Int, Int)\n Returns the current OS system time as a tuple of Ints\n\n http://erlang.org/doc/man/os.html#timestamp-0\nSynonyms:\ngleam/erlang.erlang_timestamp\ngleam/erlang erlang_timestamp","url":"gleam/erlang.html#erlang_timestamp"},{"doc":"gleam/erlang","title":"format","content":"pub fn format(term: a) -&gt; String\n Return a string representation of any term\nSynonyms:\ngleam/erlang.format\ngleam/erlang format","url":"gleam/erlang.html#format"},{"doc":"gleam/erlang","title":"get_line","content":"pub fn get_line(prompt prompt: String) -&gt; Result(\n  String,\n  GetLineError,\n)\n Reads a line from standard input with the given prompt.\n\n # Example\n\n    &gt; get_line(&quot;Language: &quot;)\n    // -&gt; Language: &lt;- gleam\n    Ok(&quot;gleam\\n&quot;)\n\nSynonyms:\ngleam/erlang.get_line\ngleam/erlang get_line","url":"gleam/erlang.html#get_line"},{"doc":"gleam/erlang","title":"make_reference","content":"pub fn make_reference() -&gt; Reference\n Create a new unique reference.\n\nSynonyms:\ngleam/erlang.make_reference\ngleam/erlang make_reference","url":"gleam/erlang.html#make_reference"},{"doc":"gleam/erlang","title":"priv_directory","content":"pub fn priv_directory(name: String) -&gt; Result(String, Nil)\n Returns the path of a package&#39;s `priv` directory, where extra non-Gleam\n or Erlang files are typically kept.\n\n Returns an error if no package was found with the given name.\n\n # Example\n\n \n &gt; erlang.priv_directory(&quot;my_app&quot;)\n // -&gt; Ok(&quot;/some/location/my_app/priv&quot;)\n \n \nSynonyms:\ngleam/erlang.priv_directory\ngleam/erlang priv_directory","url":"gleam/erlang.html#priv_directory"},{"doc":"gleam/erlang","title":"rescue","content":"pub fn rescue(a: fn() -&gt; a) -&gt; Result(a, Crash)\n Gleam doesn&#39;t offer any way to raise exceptions, but they may still occur\n due to bugs when working with unsafe code, such as when calling Erlang\n function.\n\n This function will catch any error thrown and convert it into a result\n rather than crashing the process.\n\nSynonyms:\ngleam/erlang.rescue\ngleam/erlang rescue","url":"gleam/erlang.html#rescue"},{"doc":"gleam/erlang","title":"start_arguments","content":"pub fn start_arguments() -&gt; List(String)\n Get the arguments given to the program when it was started.\n\n This is sometimes called `argv` in other languages.\nSynonyms:\ngleam/erlang.start_arguments\ngleam/erlang start_arguments","url":"gleam/erlang.html#start_arguments"},{"doc":"gleam/erlang","title":"system_time","content":"pub fn system_time(a: TimeUnit) -&gt; Int\n Returns the current OS system time.\n\n &lt;https://erlang.org/doc/apps/erts/time_correction.html#OS_System_Time&gt;\nSynonyms:\ngleam/erlang.system_time\ngleam/erlang system_time","url":"gleam/erlang.html#system_time"},{"doc":"gleam/erlang","title":"term_to_binary","content":"pub fn term_to_binary(a: a) -&gt; BitString\n\nSynonyms:\ngleam/erlang.term_to_binary\ngleam/erlang term_to_binary","url":"gleam/erlang.html#term_to_binary"},{"doc":"gleam/erlang","title":"unsafe_binary_to_term","content":"pub fn unsafe_binary_to_term(binary: BitString) -&gt; Result(\n  Dynamic,\n  Nil,\n)\n\nSynonyms:\ngleam/erlang.unsafe_binary_to_term\ngleam/erlang unsafe_binary_to_term","url":"gleam/erlang.html#unsafe_binary_to_term"},{"doc":"gleam/erlang","title":"gleam/erlang","content":"","url":"gleam/erlang.html"},{"doc":"gleam/erlang/node","title":"ConnectError","content":"pub type ConnectError {\n  FailedToConnect\n  LocalNodeIsNotAlive\n}\n\nFailedToConnect\n Was unable to connect to the node.\n\nLocalNodeIsNotAlive\n The local node is not alive, so it is not possible to connect to the other\n node.\n\nSynonyms:\ngleam/erlang/node.ConnectError\ngleam/erlang/node ConnectError","url":"gleam/erlang/node.html#ConnectError"},{"doc":"gleam/erlang/node","title":"Node","content":"pub type Node\n\n\nSynonyms:\ngleam/erlang/node.Node\ngleam/erlang/node Node","url":"gleam/erlang/node.html#Node"},{"doc":"gleam/erlang/node","title":"connect","content":"pub fn connect(node: Atom) -&gt; Result(Node, ConnectError)\n Establish a connection to a node, so the nodes can send messages to each\n other and any other connected nodes.\n\n Returns `Error(FailedToConnect)` if the node is not reachable.\n\n Returns `Error(LocalNodeIsNotAlive)` if the local node is not alive, meaning\n it is not running in distributed mode.\n\nSynonyms:\ngleam/erlang/node.connect\ngleam/erlang/node connect","url":"gleam/erlang/node.html#connect"},{"doc":"gleam/erlang/node","title":"self","content":"pub fn self() -&gt; Node\n Return the current node.\n\nSynonyms:\ngleam/erlang/node.self\ngleam/erlang/node self","url":"gleam/erlang/node.html#self"},{"doc":"gleam/erlang/node","title":"send","content":"pub fn send(node: Node, name: Atom, message: a) -&gt; Nil\n Send a message to a named process on a given node.\n\n These messages are untyped, like regular Erlang messages.\n\nSynonyms:\ngleam/erlang/node.send\ngleam/erlang/node send","url":"gleam/erlang/node.html#send"},{"doc":"gleam/erlang/node","title":"to_atom","content":"pub fn to_atom(node: Node) -&gt; Atom\n Convert a node to the atom of its name.\n\nSynonyms:\ngleam/erlang/node.to_atom\ngleam/erlang/node to_atom","url":"gleam/erlang/node.html#to_atom"},{"doc":"gleam/erlang/node","title":"visible","content":"pub fn visible() -&gt; List(Node)\n Return a list of all visible nodes in the cluster, not including the current\n node.\n\n The current node can be included by calling `self()` and prepending the\n result.\n\n \n let all_nodes = [node.self(), ..node.visible()]\n \n\nSynonyms:\ngleam/erlang/node.visible\ngleam/erlang/node visible","url":"gleam/erlang/node.html#visible"},{"doc":"gleam/erlang/node","title":"gleam/erlang/node","content":"","url":"gleam/erlang/node.html"},{"doc":"gleam/erlang/file","title":"Access","content":"pub type Access {\n  NoAccess\n  Read\n  ReadWrite\n  Write\n}\n The read/write permissions a user can have for a file.\n\nNoAccess\n\n\nRead\n\n\nReadWrite\n\n\nWrite\n\n\nSynonyms:\ngleam/erlang/file.Access\ngleam/erlang/file Access","url":"gleam/erlang/file.html#Access"},{"doc":"gleam/erlang/file","title":"FileInfo","content":"pub type FileInfo {\n  FileInfo(\n    size: Int,\n    file_type: FileType,\n    access: Access,\n    atime: Int,\n    mtime: Int,\n    ctime: Int,\n    mode: Int,\n    links: Int,\n    major_device: Int,\n    minor_device: Int,\n    inode: Int,\n    user_id: Int,\n    group_id: Int,\n  )\n}\n Meta information for a file.\n\n Timestamps are in seconds before or after the Unix time epoch,\n `1970-01-01 00:00:00 UTC`.\n\nFileInfo(\n  size: Int,\n  file_type: FileType,\n  access: Access,\n  atime: Int,\n  mtime: Int,\n  ctime: Int,\n  mode: Int,\n  links: Int,\n  major_device: Int,\n  minor_device: Int,\n  inode: Int,\n  user_id: Int,\n  group_id: Int,\n)\n\nsize\n&lt;p&gt;File size in bytes.&lt;/p&gt;\n\nfile_type\n&lt;p&gt;&lt;code&gt;Regular&lt;/code&gt;, &lt;code&gt;Directory&lt;/code&gt;, &lt;code&gt;Symlink&lt;/code&gt;, &lt;code&gt;Device&lt;/code&gt;, or &lt;code&gt;Other&lt;/code&gt;.&lt;/p&gt;\n\naccess\n&lt;p&gt;&lt;code&gt;ReadWrite&lt;/code&gt;, &lt;code&gt;Read&lt;/code&gt;, &lt;code&gt;Write&lt;/code&gt;, or &lt;code&gt;NoAccess&lt;/code&gt;.&lt;/p&gt;\n\natime\n&lt;p&gt;Timestamp of most recent access.&lt;/p&gt;\n\nmtime\n&lt;p&gt;Timestamp of most recent modification.&lt;/p&gt;\n\nctime\n&lt;p&gt;Timestamp of most recent change (or file creation, depending on\noperating system).&lt;/p&gt;\n\nmode\n&lt;p&gt;File permissions encoded as a sum of bit values, including but not\nlimited to:&lt;/p&gt;\n&lt;p&gt;Owner read, write, execute.&lt;/p&gt;\n&lt;p&gt;&lt;code&gt;0o400&lt;/code&gt;, &lt;code&gt;0o200&lt;/code&gt;, &lt;code&gt;0o100&lt;/code&gt;&lt;/p&gt;\n&lt;p&gt;Group read, write, execute.&lt;/p&gt;\n&lt;p&gt;&lt;code&gt;0o40&lt;/code&gt;, &lt;code&gt;0o20&lt;/code&gt;, &lt;code&gt;0o10&lt;/code&gt;&lt;/p&gt;\n&lt;p&gt;Other read, write, execute.&lt;/p&gt;\n&lt;p&gt;&lt;code&gt;0o4&lt;/code&gt;, &lt;code&gt;0o2&lt;/code&gt;, &lt;code&gt;0o1&lt;/code&gt;&lt;/p&gt;\n&lt;p&gt;Set user ID, group ID on execution.&lt;/p&gt;\n&lt;p&gt;&lt;code&gt;0x800&lt;/code&gt;, &lt;code&gt;0x400&lt;/code&gt;&lt;/p&gt;\n\nlinks\n&lt;p&gt;Total links to a file (always &lt;code&gt;1&lt;/code&gt; for file systems without links).&lt;/p&gt;\n\nmajor_device\n&lt;p&gt;The file system where a file is located (&lt;code&gt;0&lt;/code&gt; for drive &lt;code&gt;A:&lt;/code&gt; on Windows,\n&lt;code&gt;1&lt;/code&gt; for &lt;code&gt;B:&lt;/code&gt;, etc.).&lt;/p&gt;\n\nminor_device\n&lt;p&gt;Character device (or &lt;code&gt;0&lt;/code&gt; on non-Unix systems).&lt;/p&gt;\n\ninode\n&lt;p&gt;The &lt;code&gt;inode&lt;/code&gt; number for a file (always &lt;code&gt;0&lt;/code&gt; on non-Unix file systems).&lt;/p&gt;\n\nuser_id\n&lt;p&gt;The owner of a file (always &lt;code&gt;0&lt;/code&gt; on non-Unix file systems).&lt;/p&gt;\n\ngroup_id\n&lt;p&gt;The group id of a file (always &lt;code&gt;0&lt;/code&gt; on non-Unix file systems).&lt;/p&gt;\n\nSynonyms:\ngleam/erlang/file.FileInfo\ngleam/erlang/file FileInfo","url":"gleam/erlang/file.html#FileInfo"},{"doc":"gleam/erlang/file","title":"FileType","content":"pub type FileType {\n  Device\n  Directory\n  Other\n  Regular\n  Symlink\n}\n The type of file found by `file_info` or `link_info`.\n\nDevice\n\n\nDirectory\n\n\nOther\n\n\nRegular\n\n\nSymlink\n\n\nSynonyms:\ngleam/erlang/file.FileType\ngleam/erlang/file FileType","url":"gleam/erlang/file.html#FileType"},{"doc":"gleam/erlang/file","title":"Reason","content":"pub type Reason {\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n  NotUtf8\n}\n Reason represents all of the reasons that Erlang surfaces of why a file\n system operation could fail. Most of these reasons are POSIX errors, which\n come from the operating system and start with `E`. Others have been added to\n represent other issues that may arise.\nEacces\n Permission denied.\n\nEagain\n Resource temporarily unavailable.\n\nEbadf\n Bad file number\n\nEbadmsg\n Bad message.\n\nEbusy\n File busy.\n\nEdeadlk\n Resource deadlock avoided.\n\nEdeadlock\n On most architectures, same as `Edeadlk`. On some architectures, it\n means &quot;File locking deadlock error.&quot;\n\nEdquot\n Disk quota exceeded.\n\nEexist\n File already exists.\n\nEfault\n Bad address in system call argument.\n\nEfbig\n File too large.\n\nEftype\n Inappropriate file type or format. Usually caused by trying to set the\n &quot;sticky bit&quot; on a regular file (not a directory).\n\nEintr\n Interrupted system call.\n\nEinval\n Invalid argument.\n\nEio\n I/O error.\n\nEisdir\n Illegal operation on a directory.\n\nEloop\n Too many levels of symbolic links.\n\nEmfile\n Too many open files.\n\nEmlink\n Too many links.\n\nEmultihop\n Multihop attempted.\n\nEnametoolong\n Filename too long\n\nEnfile\n File table overflow\n\nEnobufs\n No buffer space available.\n\nEnodev\n No such device.\n\nEnolck\n No locks available.\n\nEnolink\n Link has been severed.\n\nEnoent\n No such file or directory.\n\nEnomem\n Not enough memory.\n\nEnospc\n No space left on device.\n\nEnosr\n No STREAM resources.\n\nEnostr\n Not a STREAM.\n\nEnosys\n Function not implemented.\n\nEnotblk\n Block device required.\n\nEnotdir\n Not a directory.\n\nEnotsup\n Operation not supported.\n\nEnxio\n No such device or address.\n\nEopnotsupp\n Operation not supported on socket.\n\nEoverflow\n Value too large to be stored in data type.\n\nEperm\n Not owner.\n\nEpipe\n Broken pipe.\n\nErange\n Result too large.\n\nErofs\n Read-only file system.\n\nEspipe\n Invalid seek.\n\nEsrch\n No such process.\n\nEstale\n Stale remote file handle.\n\nEtxtbsy\n Text file busy.\n\nExdev\n Cross-domain link.\n\nNotUtf8\n File was requested to be read as UTF-8, but is not UTF-8 encoded.\n\nSynonyms:\ngleam/erlang/file.Reason\ngleam/erlang/file Reason","url":"gleam/erlang/file.html#Reason"},{"doc":"gleam/erlang/file","title":"append","content":"pub fn append(contents contents: String, to path: String) -&gt; Result(\n  Nil,\n  Reason,\n)\n Append the given String contents to a file of the given name.\n\n Returns a Result with Nil if the operation was successful or a Reason\n otherwise.\n\n ## Examples\n\n \n &gt; append(&quot;Hello, World!&quot;, &quot;file.txt&quot;)\n Ok(Nil)\n\n &gt; append(to: &quot;file.txt&quot;, contents: &quot;Hello, World!&quot;)\n Ok(Nil)\n\n &gt; append(&quot;Hello, World!&quot;, &quot;does_not_exist/file.txt&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.append\ngleam/erlang/file append","url":"gleam/erlang/file.html#append"},{"doc":"gleam/erlang/file","title":"append_bits","content":"pub fn append_bits(contents contents: BitString, to path: String) -&gt; Result(\n  Nil,\n  Reason,\n)\n Append the given BitString contents to a file of the given name.\n\n Returns a Result with Nil if the operation was successful or a Reason\n otherwise.\n\n ## Examples\n\n \n &gt; append_bits(&lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;, &quot;cat.gif&quot;)\n Ok(Nil)\n\n &gt; append_bits(to: &quot;cat.gif&quot;, contents: &lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;)\n Ok(Nil)\n\n &gt; append_bits(&lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;, &quot;does_not_exist/cat.gif&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.append_bits\ngleam/erlang/file append_bits","url":"gleam/erlang/file.html#append_bits"},{"doc":"gleam/erlang/file","title":"delete","content":"pub fn delete(a: String) -&gt; Result(Nil, Reason)\n Delete the given file.\n\n Returns a Result with Nil if the operation was successful or a Reason\n otherwise.\n\n ## Examples\n\n \n &gt; delete(&quot;file.txt&quot;)\n Ok(Nil)\n\n &gt; delete(&quot;does_not_exist.txt&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.delete\ngleam/erlang/file delete","url":"gleam/erlang/file.html#delete"},{"doc":"gleam/erlang/file","title":"delete_directory","content":"pub fn delete_directory(a: String) -&gt; Result(Nil, Reason)\n Deletes a directory.\n\n The directory must be empty before it can be deleted. Returns a nil Success\n or Reason if the operation failed.\n\n ## Examples\n\n \n &gt; delete_directory(&quot;foo&quot;)\n Ok(Nil)\n\n &gt; delete_directory(&quot;does_not_exist/&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.delete_directory\ngleam/erlang/file delete_directory","url":"gleam/erlang/file.html#delete_directory"},{"doc":"gleam/erlang/file","title":"file_exists","content":"pub fn file_exists(path: String) -&gt; Result(Bool, Reason)\n Results in a `Bool` on success that indicates whether the given `path`\n exists, otherwise a `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link&#39;s target.\n To find whether a symlink itself exists, use `link_exists`.\n\n ## Examples\n\n \n &gt; file_exists(&quot;resume.pdf&quot;)\n Ok(True)\n\n &gt; file_exists(&quot;/tmp&quot;)\n Ok(True)\n\n &gt; file_exists(&quot;/does_not_exist&quot;)\n Ok(False)\n\n &gt; file_exists(&quot;/root/.local/maybe_exists&quot;)\n Error(Eacces)\n \n\nSynonyms:\ngleam/erlang/file.file_exists\ngleam/erlang/file file_exists","url":"gleam/erlang/file.html#file_exists"},{"doc":"gleam/erlang/file","title":"file_info","content":"pub fn file_info(a: String) -&gt; Result(FileInfo, Reason)\n Results in `FileInfo` about the given `path` on success, otherwise a\n `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link&#39;s target.\n To get `FileInfo` about a symlink itself, use `link_info`.\n\n ## Examples\n\n \n &gt; file_info(&quot;gleam.toml&quot;)\n Ok(FileInfo(\n   size: 430,\n   file_type: Regular,\n   access: ReadWrite,\n   atime: 1680580321,\n   mtime: 1680580272,\n   ctime: 1680580272,\n   mode: 33188,\n   links: 1,\n   major_device: 64,\n   minor_device: 0,\n   inode: 469028,\n   user_id: 1000,\n   group_id: 1000,\n ))\n\n &gt; file_info(&quot;/root&quot;)\n Ok(FileInfo(\n   size: 16,\n   file_type: Directory,\n   access: Read,\n   atime: 1677789967,\n   mtime: 1664561240,\n   ctime: 1664561240,\n   mode: 16877,\n   links: 11,\n   major_device: 54,\n   minor_device: 0,\n   inode: 34,\n   user_id: 0,\n   group_id: 0,\n ))\n\n &gt; file_info(&quot;./build/dev/erlang/rad/priv&quot;)\n Ok(FileInfo(\n   size: 140,\n   file_type: Directory,\n   access: ReadWrite,\n   atime: 1680580321,\n   mtime: 1680580272,\n   ctime: 1680580272,\n   mode: 33188,\n   links: 1,\n   major_device: 64,\n   minor_device: 0,\n   inode: 469028,\n   user_id: 1000,\n   group_id: 1000,\n ))\n\n &gt; file_info(&quot;/does_not_exist&quot;)\n Error(Enoent)\n\n &gt; file_info(&quot;/root/.local/maybe_exists&quot;)\n Error(Eacces)\n \n\nSynonyms:\ngleam/erlang/file.file_info\ngleam/erlang/file file_info","url":"gleam/erlang/file.html#file_info"},{"doc":"gleam/erlang/file","title":"is_directory","content":"pub fn is_directory(path: String) -&gt; Result(Bool, Reason)\n Results in a `Bool` on success that indicates whether the given `path` has\n a `Directory` `FileType`, otherwise a `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link&#39;s target.\n\n ## Examples\n\n \n &gt; is_directory(&quot;/tmp&quot;)\n Ok(True)\n\n &gt; is_directory(&quot;resume.pdf&quot;)\n Ok(False)\n\n &gt; is_directory(&quot;/does_not_exist&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.is_directory\ngleam/erlang/file is_directory","url":"gleam/erlang/file.html#is_directory"},{"doc":"gleam/erlang/file","title":"is_regular","content":"pub fn is_regular(path: String) -&gt; Result(Bool, Reason)\n Results in a `Bool` on success that indicates whether the given `path` has\n a `Regular` `FileType`, otherwise a `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link&#39;s target.\n\n ## Examples\n\n \n &gt; is_regular(&quot;resume.pdf&quot;)\n Ok(True)\n\n &gt; is_regular(&quot;/tmp&quot;)\n Ok(False)\n\n &gt; is_regular(&quot;/does_not_exist.txt&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.is_regular\ngleam/erlang/file is_regular","url":"gleam/erlang/file.html#is_regular"},{"doc":"gleam/erlang/file","title":"link_exists","content":"pub fn link_exists(path: String) -&gt; Result(Bool, Reason)\n Results in a `Bool` on success that indicates whether the given `path`\n exists, otherwise a `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link itself.\n To find whether a symlink&#39;s target exists, use `file_exists`.\n\n ## Examples\n\n \n &gt; link_exists(&quot;resume.pdf&quot;)\n Ok(True)\n\n &gt; link_exists(&quot;/tmp&quot;)\n Ok(True)\n\n &gt; link_exists(&quot;/does_not_exist&quot;)\n Ok(False)\n\n &gt; link_exists(&quot;/root/.local/maybe_exists&quot;)\n Error(Eacces)\n \n\nSynonyms:\ngleam/erlang/file.link_exists\ngleam/erlang/file link_exists","url":"gleam/erlang/file.html#link_exists"},{"doc":"gleam/erlang/file","title":"link_info","content":"pub fn link_info(a: String) -&gt; Result(FileInfo, Reason)\n Results in `FileInfo` about the given `path` on success, otherwise a\n `Reason` for failure.\n\n When `path` refers to a symlink, the result pertains to the link itself.\n To get `FileInfo` about a symlink&#39;s target, use `file_info`.\n\n ## Examples\n\n \n &gt; link_info(&quot;gleam.toml&quot;)\n Ok(FileInfo(\n   size: 430,\n   file_type: Regular,\n   access: ReadWrite,\n   atime: 1680580321,\n   mtime: 1680580272,\n   ctime: 1680580272,\n   mode: 33188,\n   links: 1,\n   major_device: 64,\n   minor_device: 0,\n   inode: 469028,\n   user_id: 1000,\n   group_id: 1000,\n ))\n\n &gt; link_info(&quot;/root&quot;)\n Ok(FileInfo(\n   size: 16,\n   file_type: Directory,\n   access: Read,\n   atime: 1677789967,\n   mtime: 1664561240,\n   ctime: 1664561240,\n   mode: 16877,\n   links: 11,\n   major_device: 54,\n   minor_device: 0,\n   inode: 34,\n   user_id: 0,\n   group_id: 0,\n ))\n\n &gt; link_info(&quot;./build/dev/erlang/rad/priv&quot;)\n Ok(FileInfo(\n   size: 41,\n   file_type: Symlink,\n   access: ReadWrite,\n   atime: 1680581150,\n   mtime: 1680581150,\n   ctime: 1680581150,\n   mode: 41471,\n   links: 1,\n   major_device: 64,\n   minor_device: 0,\n   inode: 471587,\n   user_id: 1000,\n   group_id: 1000,\n ))\n\n &gt; link_info(&quot;/does_not_exist&quot;)\n Error(Enoent)\n\n &gt; link_info(&quot;/root/.local/maybe_exists&quot;)\n Error(Eacces)\n \n\nSynonyms:\ngleam/erlang/file.link_info\ngleam/erlang/file link_info","url":"gleam/erlang/file.html#link_info"},{"doc":"gleam/erlang/file","title":"list_directory","content":"pub fn list_directory(a: String) -&gt; Result(List(String), Reason)\n Lists all files in a directory, except files with\n [raw filenames](https://www.erlang.org/doc/apps/stdlib/unicode_usage.html#notes-about-raw-filenames).\n\n Returns a Result containing the list of filenames in the directory, or Reason\n if the operation failed.\n\n ## Examples\n\n \n &gt; list_directory(&quot;/tmp&quot;)\n Ok([&quot;FB01293B-8597-4359-80D5-130140A0C0DE&quot;,&quot;AlTest2.out&quot;])\n\n &gt; list_directory(&quot;resume.docx&quot;)\n Error(Enotdir)\n \n\nSynonyms:\ngleam/erlang/file.list_directory\ngleam/erlang/file list_directory","url":"gleam/erlang/file.html#list_directory"},{"doc":"gleam/erlang/file","title":"make_directory","content":"pub fn make_directory(a: String) -&gt; Result(Nil, Reason)\n Tries to create a directory. Missing parent directories are not created.\n\n Returns a Result of nil if the directory is created or Reason if the\n operation failed.\n\n ## Examples\n\n \n &gt; make_directory(&quot;/tmp/foo&quot;)\n Ok(Nil)\n\n &gt; make_directory(&quot;relative_directory&quot;)\n Ok(Nil)\n\n &gt; make_directory(&quot;/tmp/missing_intermediate_directory/foo&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.make_directory\ngleam/erlang/file make_directory","url":"gleam/erlang/file.html#make_directory"},{"doc":"gleam/erlang/file","title":"read","content":"pub fn read(from path: String) -&gt; Result(String, Reason)\n Read the contents of the given file as a String\n\n Assumes the file is UTF-8 encoded. Returns a Result containing the file&#39;s\n contents as a String if the operation was successful, or Reason if the file\n operation failed. If the file is not UTF-8 encoded, the `NotUTF8` variant\n will be returned.\n\n ## Examples\n\n \n &gt; read(&quot;example.txt&quot;)\n Ok(&quot;Hello, World!&quot;)\n\n &gt; read(from: &quot;example.txt&quot;)\n Ok(&quot;Hello, World!&quot;)\n\n &gt; read(&quot;does_not_exist.txt&quot;)\n Error(Enoent)\n\n &gt; read(&quot;cat.gif&quot;)\n Error(NotUTF8)\n \n\nSynonyms:\ngleam/erlang/file.read\ngleam/erlang/file read","url":"gleam/erlang/file.html#read"},{"doc":"gleam/erlang/file","title":"read_bits","content":"pub fn read_bits(from path: String) -&gt; Result(BitString, Reason)\n Read the contents of the given file as a BitString\n\n Returns a Result containing the file&#39;s contents as a BitString if the\n operation was successful, or Reason if the operation failed.\n\n ## Examples\n\n \n &gt; read_bits(&quot;example.txt&quot;)\n Ok(&lt;&lt;&quot;Hello, World!&quot;&gt;&gt;)\n\n &gt; read_bits(from: &quot;cat.gif&quot;)\n Ok(&lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;)\n\n &gt; read_bits(&quot;does_not_exist.txt&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.read_bits\ngleam/erlang/file read_bits","url":"gleam/erlang/file.html#read_bits"},{"doc":"gleam/erlang/file","title":"recursive_delete","content":"pub fn recursive_delete(a: String) -&gt; Result(Nil, Reason)\n Deletes a file or directory recursively.\n\n Returns a nil Success or Reason if the operation failed.\n\n ## Examples\n\n \n &gt; recursive_delete(&quot;foo&quot;)\n Ok(Nil)\n\n &gt; recursive_delete(&quot;/bar&quot;)\n Ok(Nil)\n\n &gt; recursive_delete(&quot;does_not_exist/&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.recursive_delete\ngleam/erlang/file recursive_delete","url":"gleam/erlang/file.html#recursive_delete"},{"doc":"gleam/erlang/file","title":"write","content":"pub fn write(contents contents: String, to path: String) -&gt; Result(\n  Nil,\n  Reason,\n)\n Write the given String contents to a file of the given name.\n\n Returns a Result with Nil if the operation was successful or a Reason\n otherwise.\n\n ## Examples\n\n \n &gt; write(&quot;Hello, World!&quot;, &quot;file.txt&quot;)\n Ok(Nil)\n\n &gt; write(to: &quot;file.txt&quot;, contents: &quot;Hello, World!&quot;)\n Ok(Nil)\n\n &gt; write(&quot;Hello, World!&quot;, &quot;does_not_exist/file.txt&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.write\ngleam/erlang/file write","url":"gleam/erlang/file.html#write"},{"doc":"gleam/erlang/file","title":"write_bits","content":"pub fn write_bits(contents contents: BitString, to path: String) -&gt; Result(\n  Nil,\n  Reason,\n)\n Write the given BitString contents to a file of the given name.\n\n Returns a Result with Nil if the operation was successful or a Reason\n otherwise.\n\n ## Examples\n\n \n &gt; write_bits(&lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;, &quot;cat.gif&quot;)\n Ok(Nil)\n\n &gt; write_bits(to: &quot;cat.gif&quot;, contents: &lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;)\n Ok(Nil)\n\n &gt; write_bits(&lt;&lt;71,73,70,56,57,97,1,0,1,0,0,0,0,59&gt;&gt;, &quot;does_not_exist/cat.gif&quot;)\n Error(Enoent)\n \n\nSynonyms:\ngleam/erlang/file.write_bits\ngleam/erlang/file write_bits","url":"gleam/erlang/file.html#write_bits"},{"doc":"gleam/erlang/file","title":"gleam/erlang/file","content":" Working with files on the filesystem.\n\n The functions included in this module are for high-level concepts such as\n reading and writing.","url":"gleam/erlang/file.html"},{"doc":"gleam/erlang/process","title":"CallError","content":"pub type CallError(msg) {\n  CalleeDown(reason: Dynamic)\n  CallTimeout\n}\n An error returned when making a call to a process.\n\nCalleeDown(reason: Dynamic)\n The process being called exited before it sent a response.\n\n\nCallTimeout\n The process being called did not response within the permitted amount of\n time.\n\n\nSynonyms:\ngleam/erlang/process.CallError\ngleam/erlang/process CallError","url":"gleam/erlang/process.html#CallError"},{"doc":"gleam/erlang/process","title":"Cancelled","content":"pub type Cancelled {\n  TimerNotFound\n  Cancelled(time_remaining: Int)\n}\n Values returned when a timer is cancelled.\n\nTimerNotFound\n The timer could not be found. It likely has already triggered.\n\n\nCancelled(time_remaining: Int)\n The timer was found and cancelled before it triggered.\n\n The amount of remaining time before the timer was due to be triggered is\n returned in milliseconds.\n\n\nSynonyms:\ngleam/erlang/process.Cancelled\ngleam/erlang/process Cancelled","url":"gleam/erlang/process.html#Cancelled"},{"doc":"gleam/erlang/process","title":"ExitMessage","content":"pub type ExitMessage {\n  ExitMessage(pid: Pid, reason: ExitReason)\n}\n\nExitMessage(pid: Pid, reason: ExitReason)\n\n\nSynonyms:\ngleam/erlang/process.ExitMessage\ngleam/erlang/process ExitMessage","url":"gleam/erlang/process.html#ExitMessage"},{"doc":"gleam/erlang/process","title":"ExitReason","content":"pub type ExitReason {\n  Normal\n  Killed\n  Abnormal(reason: String)\n}\n\nNormal\n\n\nKilled\n\n\nAbnormal(reason: String)\n\n\nSynonyms:\ngleam/erlang/process.ExitReason\ngleam/erlang/process ExitReason","url":"gleam/erlang/process.html#ExitReason"},{"doc":"gleam/erlang/process","title":"Pid","content":"pub type Pid\n A `Pid` (or Process identifier) is a reference to an Erlang process. Each\n process has a `Pid` and it is one of the lowest level building blocks of\n inter-process communication in the Erlang and Gleam OTP frameworks.\n\n\nSynonyms:\ngleam/erlang/process.Pid\ngleam/erlang/process Pid","url":"gleam/erlang/process.html#Pid"},{"doc":"gleam/erlang/process","title":"ProcessDown","content":"pub type ProcessDown {\n  ProcessDown(pid: Pid, reason: Dynamic)\n}\n A message received when a monitored process exits.\n\nProcessDown(pid: Pid, reason: Dynamic)\n\n\nSynonyms:\ngleam/erlang/process.ProcessDown\ngleam/erlang/process ProcessDown","url":"gleam/erlang/process.html#ProcessDown"},{"doc":"gleam/erlang/process","title":"ProcessMonitor","content":"pub opaque type ProcessMonitor\n\n\nSynonyms:\ngleam/erlang/process.ProcessMonitor\ngleam/erlang/process ProcessMonitor","url":"gleam/erlang/process.html#ProcessMonitor"},{"doc":"gleam/erlang/process","title":"Selector","content":"pub type Selector(payload)\n A type that enables a process to wait for messages from multiple `Subject`s\n at the same time, returning whichever message arrives first.\n\n Used with the `new_selector`, `selecting`, and `select` functions.\n\n # Examples\n\n \n &gt; let int_subject = new_subject()\n &gt; let float_subject = new_subject()\n &gt; send(int_subject, 1)\n &gt;\n &gt; let selector =\n &gt;   new_selector()\n &gt;   |&gt; selecting(int_subject, int.to_string)\n &gt;   |&gt; selecting(float_subject, float.to_string)\n &gt;\n &gt; select(selector)\n Ok(&quot;1&quot;)\n \n\n\nSynonyms:\ngleam/erlang/process.Selector\ngleam/erlang/process Selector","url":"gleam/erlang/process.html#Selector"},{"doc":"gleam/erlang/process","title":"Subject","content":"pub opaque type Subject(message)\n A `Subject` is a value that processes can use to send and receive messages\n to and from each other in a well typed way.\n\n Each subject is &quot;owned&quot; by the process that created it. Any process can use\n the `send` function to sent a message of the correct type to the process\n that owns the subject, and the owner can use the `receive` function or the\n `Selector` type to receive these messages.\n\n The `Subject` type is similar to the &quot;channel&quot; types found in other\n languages and the &quot;topic&quot; concept found in some pub-sub systems.\n\n # Examples\n\n \n let subject = new_subject()\n\n // Send a message with the subject\n send(subject, &quot;Hello, Joe!&quot;)\n\n // Receive the message\n receive(subject, within: 10)\n \n\n\nSynonyms:\ngleam/erlang/process.Subject\ngleam/erlang/process Subject","url":"gleam/erlang/process.html#Subject"},{"doc":"gleam/erlang/process","title":"Timer","content":"pub type Timer\n\n\nSynonyms:\ngleam/erlang/process.Timer\ngleam/erlang/process Timer","url":"gleam/erlang/process.html#Timer"},{"doc":"gleam/erlang/process","title":"call","content":"pub fn call(subject: Subject(a), make_request: fn(Subject(b)) -&gt;\n    a, within timeout: Int) -&gt; b\n Send a message to a process and wait for a reply.\n\n If the receiving process exits or does not reply within the allowed amount\n of time the calling process crashes. If you wish an error to be returned\n instead see the `try_call` function.\n\nSynonyms:\ngleam/erlang/process.call\ngleam/erlang/process call","url":"gleam/erlang/process.html#call"},{"doc":"gleam/erlang/process","title":"cancel_timer","content":"pub fn cancel_timer(timer: Timer) -&gt; Cancelled\n Cancel a given timer, causing it not to trigger if it has not done already.\n\nSynonyms:\ngleam/erlang/process.cancel_timer\ngleam/erlang/process cancel_timer","url":"gleam/erlang/process.html#cancel_timer"},{"doc":"gleam/erlang/process","title":"demonitor_process","content":"pub fn demonitor_process(monitor monitor: ProcessMonitor) -&gt; Nil\n Remove the monitor for a process so that when the monitor process exits a\n `ProcessDown` message is not sent to the monitoring process.\n\n If the message has already been sent it is removed from the monitoring\n process&#39; mailbox.\n\nSynonyms:\ngleam/erlang/process.demonitor_process\ngleam/erlang/process demonitor_process","url":"gleam/erlang/process.html#demonitor_process"},{"doc":"gleam/erlang/process","title":"flush_messages","content":"pub fn flush_messages() -&gt; Nil\n Discard all messages in the current process&#39; mailbox.\n\n Warning: This function may cause other processes to crash if they sent a\n message to the current process and are waiting for a response, so use with\n caution.\n\nSynonyms:\ngleam/erlang/process.flush_messages\ngleam/erlang/process flush_messages","url":"gleam/erlang/process.html#flush_messages"},{"doc":"gleam/erlang/process","title":"is_alive","content":"pub fn is_alive(a: Pid) -&gt; Bool\n Check to see whether the process for a given `Pid` is alive.\n\n See the [Erlang documentation][1] for more information.\n\n [1]: http://erlang.org/doc/man/erlang.html#is_process_alive-1\n\nSynonyms:\ngleam/erlang/process.is_alive\ngleam/erlang/process is_alive","url":"gleam/erlang/process.html#is_alive"},{"doc":"gleam/erlang/process","title":"kill","content":"pub fn kill(pid: Pid) -&gt; Nil\n Send an untrappable `kill` exit signal to the target process.\n\n See the documentation for the Erlang [`erlang:exit`][1] function for more\n information.\n\n [1]: https://erlang.org/doc/man/erlang.html#exit-1\n\nSynonyms:\ngleam/erlang/process.kill\ngleam/erlang/process kill","url":"gleam/erlang/process.html#kill"},{"doc":"gleam/erlang/process","title":"link","content":"pub fn link(pid pid: Pid) -&gt; Bool\n Creates a link between the calling process and another process.\n\n When a process crashes any linked processes will also crash. This is useful\n to ensure that groups of processes that depend on each other all either\n succeed or fail together.\n\n Returns `True` if the link was created successfully, returns `False` if the\n process was not alive and as such could not be linked.\n\nSynonyms:\ngleam/erlang/process.link\ngleam/erlang/process link","url":"gleam/erlang/process.html#link"},{"doc":"gleam/erlang/process","title":"map_selector","content":"pub fn map_selector(a: Selector(a), b: fn(a) -&gt; b) -&gt; Selector(b)\n Add a transformation function to a selector. When a message is received\n using this selector the tranformation function is applied to the message.\n\n This function can be used to change the type of messages received and may\n be useful when combined with the `merge_selector` function.\n\nSynonyms:\ngleam/erlang/process.map_selector\ngleam/erlang/process map_selector","url":"gleam/erlang/process.html#map_selector"},{"doc":"gleam/erlang/process","title":"merge_selector","content":"pub fn merge_selector(a: Selector(a), b: Selector(a)) -&gt; Selector(\n  a,\n)\n Merge one selector into another, producing a selector that contains the\n message handlers of both.\n\n If a subject is handled by both selectors the handler function of the\n second selector is used.\n\nSynonyms:\ngleam/erlang/process.merge_selector\ngleam/erlang/process merge_selector","url":"gleam/erlang/process.html#merge_selector"},{"doc":"gleam/erlang/process","title":"monitor_process","content":"pub fn monitor_process(pid: Pid) -&gt; ProcessMonitor\n Start monitoring a process so that when the monitored process exits a\n message is sent to the monitoring process.\n\n The message is only sent once, when the target process exits. If the\n process was not alive when this function is called the message will never\n be received.\n\n The down message can be received with a `Selector` and the\n `selecting_process_down` function.\n\n The process can be demonitored with the `demonitor_process` function.\n\nSynonyms:\ngleam/erlang/process.monitor_process\ngleam/erlang/process monitor_process","url":"gleam/erlang/process.html#monitor_process"},{"doc":"gleam/erlang/process","title":"named","content":"pub fn named(name: Atom) -&gt; Result(Pid, Nil)\n Look up a process by name, returning the pid if it exists.\n\nSynonyms:\ngleam/erlang/process.named\ngleam/erlang/process named","url":"gleam/erlang/process.html#named"},{"doc":"gleam/erlang/process","title":"new_selector","content":"pub fn new_selector() -&gt; Selector(a)\n Create a new `Selector` which can be used to receive messages on multiple\n `Subject`s at once.\n\nSynonyms:\ngleam/erlang/process.new_selector\ngleam/erlang/process new_selector","url":"gleam/erlang/process.html#new_selector"},{"doc":"gleam/erlang/process","title":"new_subject","content":"pub fn new_subject() -&gt; Subject(a)\n Create a new `Subject` owned by the current process.\n\nSynonyms:\ngleam/erlang/process.new_subject\ngleam/erlang/process new_subject","url":"gleam/erlang/process.html#new_subject"},{"doc":"gleam/erlang/process","title":"receive","content":"pub fn receive(from subject: Subject(a), within milliseconds: Int) -&gt; Result(\n  a,\n  Nil,\n)\n Receive a message that has been sent to current process using the `Subject`.\n\n If there is not an existing message for the `Subject` in the process&#39;\n mailbox or one does not arrive `within` the permitted timeout then the\n `Error(Nil)` is returned.\n\n Only the process that is owner of the `Subject` can receive a message using\n it. If a process that does not own the `Subject` attempts to receive with it\n then it will not receive a message.\n\n To wait for messages from multiple `Subject`s at the same time see the\n `Selector` type.\n\nSynonyms:\ngleam/erlang/process.receive\ngleam/erlang/process receive","url":"gleam/erlang/process.html#receive"},{"doc":"gleam/erlang/process","title":"register","content":"pub fn register(pid: Pid, name: Atom) -&gt; Result(Nil, Nil)\n Register a process under a given name, allowing it to be looked up using\n the `named` function.\n\n This function will return an error under the following conditions:\n - The process for the pid no longer exists.\n - The name has already been registered.\n - The process already has a name.\n - The name is the atom `undefined`, which is reserved by Erlang. \n\nSynonyms:\ngleam/erlang/process.register\ngleam/erlang/process register","url":"gleam/erlang/process.html#register"},{"doc":"gleam/erlang/process","title":"select","content":"pub fn select(from from: Selector(a), within within: Int) -&gt; Result(\n  a,\n  Nil,\n)\n Receive a message that has been sent to current process using any of the\n `Subject`s that have been added to the `Selector` with the `selecting`\n function.\n\n If there is not an existing message for the `Selector` in the process&#39;\n mailbox or one does not arrive `within` the permitted timeout then the\n `Error(Nil)` is returned.\n\n Only the process that is owner of the `Subject`s can receive a message using\n them. If a process that does not own the a `Subject` attempts to receive\n with it then it will not receive a message.\n\n To wait forever for the next message rather than for a limited amount of\n time see the `select_forever` function.\n\nSynonyms:\ngleam/erlang/process.select\ngleam/erlang/process select","url":"gleam/erlang/process.html#select"},{"doc":"gleam/erlang/process","title":"select_forever","content":"pub fn select_forever(from from: Selector(a)) -&gt; a\n Similar to the `select` function but will wait forever for a message to\n arrive rather than timing out after a specified amount of time.\n\nSynonyms:\ngleam/erlang/process.select_forever\ngleam/erlang/process select_forever","url":"gleam/erlang/process.html#select_forever"},{"doc":"gleam/erlang/process","title":"selecting","content":"pub fn selecting(selector: Selector(a), for subject: Subject(b), mapping transform: fn(\n    b,\n  ) -&gt; a) -&gt; Selector(a)\n Add a new `Subject` to the `Selector` to that it&#39;s messages can be received.\n\n The `mapping` function provided with the `Subject` can be used to convert\n the type of messages received using this `Subject`. This is useful for when\n you wish to add multiple `Subject`s to a `Seletor` when they have differing\n message types. If you do not wish to transform the incoming messages in any\n way then the `identity` function can be given.\n\nSynonyms:\ngleam/erlang/process.selecting\ngleam/erlang/process selecting","url":"gleam/erlang/process.html#selecting"},{"doc":"gleam/erlang/process","title":"selecting_anything","content":"pub fn selecting_anything(selector: Selector(a), mapping handler: fn(\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a catch-all handler to a selector that will be used when no other\n handler in a selector is suitable for a given message.\n\n This may be useful for when you want to ensure that any message in the inbox\n is handled, or when you need to handle messages from other BEAM languages\n which do not use subjects or record format messages.\n\nSynonyms:\ngleam/erlang/process.selecting_anything\ngleam/erlang/process selecting_anything","url":"gleam/erlang/process.html#selecting_anything"},{"doc":"gleam/erlang/process","title":"selecting_process_down","content":"pub fn selecting_process_down(selector: Selector(a), monitor: ProcessMonitor, mapping: fn(\n    ProcessDown,\n  ) -&gt; a) -&gt; Selector(a)\n Add a `ProcessMonitor` to a `Selector` so that the `ProcessDown` message can\n be received using the `Selector` and the `select` function.\n\nSynonyms:\ngleam/erlang/process.selecting_process_down\ngleam/erlang/process selecting_process_down","url":"gleam/erlang/process.html#selecting_process_down"},{"doc":"gleam/erlang/process","title":"selecting_record2","content":"pub fn selecting_record2(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 2 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record2\ngleam/erlang/process selecting_record2","url":"gleam/erlang/process.html#selecting_record2"},{"doc":"gleam/erlang/process","title":"selecting_record3","content":"pub fn selecting_record3(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 3 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record3\ngleam/erlang/process selecting_record3","url":"gleam/erlang/process.html#selecting_record3"},{"doc":"gleam/erlang/process","title":"selecting_record4","content":"pub fn selecting_record4(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 4 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record4\ngleam/erlang/process selecting_record4","url":"gleam/erlang/process.html#selecting_record4"},{"doc":"gleam/erlang/process","title":"selecting_record5","content":"pub fn selecting_record5(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 5 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record5\ngleam/erlang/process selecting_record5","url":"gleam/erlang/process.html#selecting_record5"},{"doc":"gleam/erlang/process","title":"selecting_record6","content":"pub fn selecting_record6(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 6 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record6\ngleam/erlang/process selecting_record6","url":"gleam/erlang/process.html#selecting_record6"},{"doc":"gleam/erlang/process","title":"selecting_record7","content":"pub fn selecting_record7(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 7 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record7\ngleam/erlang/process selecting_record7","url":"gleam/erlang/process.html#selecting_record7"},{"doc":"gleam/erlang/process","title":"selecting_record8","content":"pub fn selecting_record8(selector: Selector(a), tag: b, mapping transform: fn(\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n    Dynamic,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler to a selector for 8 element tuple messages with a given tag\n element in the first position.\n\n Typically you want to use the `selecting` function with a `Subject` instead,\n but this function may be useful if you need to receive messages sent from\n other BEAM languages that do not use the `Subject` type.\n\nSynonyms:\ngleam/erlang/process.selecting_record8\ngleam/erlang/process selecting_record8","url":"gleam/erlang/process.html#selecting_record8"},{"doc":"gleam/erlang/process","title":"selecting_trapped_exits","content":"pub fn selecting_trapped_exits(selector: Selector(a), handler: fn(\n    ExitMessage,\n  ) -&gt; a) -&gt; Selector(a)\n Add a handler for trapped exit messages. In order for these messages to be\n sent to the process when a linked process exits the process must call the\n `trap_exit` beforehand.\n\nSynonyms:\ngleam/erlang/process.selecting_trapped_exits\ngleam/erlang/process selecting_trapped_exits","url":"gleam/erlang/process.html#selecting_trapped_exits"},{"doc":"gleam/erlang/process","title":"self","content":"pub fn self() -&gt; Pid\n Get the `Pid` for the current process.\nSynonyms:\ngleam/erlang/process.self\ngleam/erlang/process self","url":"gleam/erlang/process.html#self"},{"doc":"gleam/erlang/process","title":"send","content":"pub fn send(subject: Subject(a), message: a) -&gt; Nil\n Send a message to a process using a `Subject`. The message must be of the\n type that the `Subject` accepts.\n\n This function does not wait for the `Subject` owner process to call the\n `receive` function, instead it returns once the message has been placed in\n the process&#39; mailbox.\n\n # Ordering\n\n If process P1 sends two messages to process P2 it is guarenteed that process\n P1 will receive the messages in the order they were sent.\n\n If you wish to receive the messages in a different order you can send them\n on two different subjects and the receiver function can call the `receive`\n function for each subject in the desired order, or you can write some Erlang\n code to perform a selective receive.\n\n # Examples\n\n \n let subject = new_subject()\n send(subject, &quot;Hello, Joe!&quot;)\n \n\nSynonyms:\ngleam/erlang/process.send\ngleam/erlang/process send","url":"gleam/erlang/process.html#send"},{"doc":"gleam/erlang/process","title":"send_abnormal_exit","content":"pub fn send_abnormal_exit(pid: Pid, reason: String) -&gt; Nil\n Sends an exit signal to a process, indicating that the process is to shut\n down due to an abnormal reason such as a failure.\n\n See the [Erlang documentation][erl] for more information.\n [erl]: http://erlang.org/doc/man/erlang.html#exit-2\n\nSynonyms:\ngleam/erlang/process.send_abnormal_exit\ngleam/erlang/process send_abnormal_exit","url":"gleam/erlang/process.html#send_abnormal_exit"},{"doc":"gleam/erlang/process","title":"send_after","content":"pub fn send_after(subject: Subject(a), delay: Int, message: a) -&gt; Timer\n Send a message over a channel after a specified number of milliseconds.\n\nSynonyms:\ngleam/erlang/process.send_after\ngleam/erlang/process send_after","url":"gleam/erlang/process.html#send_after"},{"doc":"gleam/erlang/process","title":"send_exit","content":"pub fn send_exit(to pid: Pid) -&gt; Nil\n Sends an exit signal to a process, indicating that the process is to shut\n down.\n\n See the [Erlang documentation][erl] for more information.\n [erl]: http://erlang.org/doc/man/erlang.html#exit-2\n\nSynonyms:\ngleam/erlang/process.send_exit\ngleam/erlang/process send_exit","url":"gleam/erlang/process.html#send_exit"},{"doc":"gleam/erlang/process","title":"sleep","content":"pub fn sleep(a: Int) -&gt; Nil\n Suspends the process calling this function for the specified number of\n milliseconds.\n\nSynonyms:\ngleam/erlang/process.sleep\ngleam/erlang/process sleep","url":"gleam/erlang/process.html#sleep"},{"doc":"gleam/erlang/process","title":"sleep_forever","content":"pub fn sleep_forever() -&gt; Nil\n Suspends the process forever! This may be useful for suspending the main\n process in a Gleam program when it has no more work to do but we want other\n processes to continue to work.\n\nSynonyms:\ngleam/erlang/process.sleep_forever\ngleam/erlang/process sleep_forever","url":"gleam/erlang/process.html#sleep_forever"},{"doc":"gleam/erlang/process","title":"start","content":"pub fn start(running implementation: fn() -&gt; a, linked link: Bool) -&gt; Pid\n Create a new Erlang process that runs concurrently to the creator. In other\n languages this might be called a fibre, a green thread, or a coroutine.\n\n If `linked` is `True` then the created process is linked to the creator\n process. When a process terminates an exit signal is sent to all other\n processes that are linked to it, causing the process to either terminate or\n have to handle the signal.\n\n More can be read about processes and links in the [Erlang documentation][1].\n\n [1]: https://www.erlang.org/doc/reference_manual/processes.html\n\nSynonyms:\ngleam/erlang/process.start\ngleam/erlang/process start","url":"gleam/erlang/process.html#start"},{"doc":"gleam/erlang/process","title":"subject_owner","content":"pub fn subject_owner(subject: Subject(a)) -&gt; Pid\n Get the owner process for a `Subject`. This is the process that created the\n `Subject` and will receive messages sent with it.\n\nSynonyms:\ngleam/erlang/process.subject_owner\ngleam/erlang/process subject_owner","url":"gleam/erlang/process.html#subject_owner"},{"doc":"gleam/erlang/process","title":"trap_exits","content":"pub fn trap_exits(a: Bool) -&gt; Nil\n Set whether the current process is to trap exit signals or not.\n\n When not trapping exits if a linked process crashes the exit signal\n propagates to the process which will also crash.\n This is the normal behaviour before this function is called.\n\n When trapping exits (after this function is called) if a linked process\n crashes an exit message is sent to the process instead. These messages can\n be handled with the `selecting_trapped_exits` function.\n\nSynonyms:\ngleam/erlang/process.trap_exits\ngleam/erlang/process trap_exits","url":"gleam/erlang/process.html#trap_exits"},{"doc":"gleam/erlang/process","title":"try_call","content":"pub fn try_call(subject: Subject(a), make_request: fn(Subject(b)) -&gt;\n    a, within timeout: Int) -&gt; Result(b, CallError(b))\n Send a message to a process and wait for a reply.\n\n If the receiving process exits or does not reply within the allowed amount\n of time then an error is returned.\n\nSynonyms:\ngleam/erlang/process.try_call\ngleam/erlang/process try_call","url":"gleam/erlang/process.html#try_call"},{"doc":"gleam/erlang/process","title":"unlink","content":"pub fn unlink(pid: Pid) -&gt; Nil\n Removes any existing link between the caller process and the target process.\n\nSynonyms:\ngleam/erlang/process.unlink\ngleam/erlang/process unlink","url":"gleam/erlang/process.html#unlink"},{"doc":"gleam/erlang/process","title":"unregister","content":"pub fn unregister(name: Atom) -&gt; Result(Nil, Nil)\n Un-register a process name, after which the process can no longer be looked\n up by that name, and both the name and the process can be re-used in other\n registrations.\n\n It is possible to un-register process that are not from your application,\n including those from Erlang/OTP itself. This is not recommended and will\n likely result in undesirable behaviour and crashes.\n\nSynonyms:\ngleam/erlang/process.unregister\ngleam/erlang/process unregister","url":"gleam/erlang/process.html#unregister"},{"doc":"gleam/erlang/process","title":"gleam/erlang/process","content":"","url":"gleam/erlang/process.html"}]);